"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var HTMLElement_1 = __importDefault(require("../html-element/HTMLElement"));
var ValidityState_1 = __importDefault(require("./ValidityState"));
var DOMException_1 = __importDefault(require("../../exception/DOMException"));
var DOMExceptionNameEnum_1 = __importDefault(require("../../exception/DOMExceptionNameEnum"));
var Event_1 = __importDefault(require("../../event/Event"));
var HTMLInputElementValueSanitizer_1 = __importDefault(require("./HTMLInputElementValueSanitizer"));
var HTMLInputElementSelectionModeEnum_1 = __importDefault(require("./HTMLInputElementSelectionModeEnum"));
var HTMLInputElementSelectionDirectionEnum_1 = __importDefault(require("./HTMLInputElementSelectionDirectionEnum"));
/**
 * HTML Input Element.
 *
 * Reference:
 * https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement
 *
 * Used as reference for some of the logic (like selection range):
 * https://github.com/jsdom/jsdom/blob/master/lib/jsdom/living/nodes/nodes/HTMLInputElement-impl.js (MIT licensed)
 */
var HTMLInputElement = /** @class */ (function (_super) {
    __extends(HTMLInputElement, _super);
    function HTMLInputElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        // Related to parent form.
        _this.formAction = '';
        _this.formMethod = '';
        _this.formNoValidate = false;
        // Any type of input
        _this._value = null;
        _this._height = 0;
        _this._width = 0;
        // Type specific: checkbox/radio
        _this.defaultChecked = false;
        // Type specific: file
        _this.files = [];
        // Type specific: text/password/search/tel/url/week/month
        _this._selectionStart = null;
        _this._selectionEnd = null;
        _this._selectionDirection = HTMLInputElementSelectionDirectionEnum_1.default.none;
        // Not categorized
        _this.defaultValue = '';
        return _this;
    }
    Object.defineProperty(HTMLInputElement.prototype, "height", {
        /**
         * Returns height.
         *
         * @return Height.
         */
        get: function () {
            return this._height;
        },
        /**
         * Sets height.
         *
         * @param height Height.
         */
        set: function (height) {
            this._height = height;
            this.setAttributeNS(null, 'height', String(height));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "width", {
        /**
         * Returns width.
         *
         * @return Width.
         */
        get: function () {
            return this._width;
        },
        /**
         * Sets width.
         *
         * @param width Width.
         */
        set: function (width) {
            this._width = width;
            this.setAttributeNS(null, 'width', String(width));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "size", {
        /**
         * Returns size.
         *
         * @return Size.
         */
        get: function () {
            var size = this.getAttributeNS(null, 'size');
            if (size !== null) {
                return parseInt(size);
            }
            return 20;
        },
        /**
         * Sets size.
         *
         * @param size Size.
         */
        set: function (size) {
            this.setAttributeNS(null, 'size', String(size));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "minLength", {
        /**
         * Returns minlength.
         *
         * @return Min length.
         */
        get: function () {
            var minLength = this.getAttributeNS(null, 'minlength');
            if (minLength !== null) {
                return parseInt(minLength);
            }
            return -1;
        },
        /**
         * Sets minlength.
         *
         * @param minLength Min length.
         */
        set: function (minlength) {
            this.setAttributeNS(null, 'minlength', String(minlength));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "maxLength", {
        /**
         * Returns maxlength.
         *
         * @return Max length.
         */
        get: function () {
            var maxLength = this.getAttributeNS(null, 'maxlength');
            if (maxLength !== null) {
                return parseInt(maxLength);
            }
            return -1;
        },
        /**
         * Sets maxlength.
         *
         * @param maxlength Max length.
         */
        set: function (maxLength) {
            this.setAttributeNS(null, 'maxlength', String(maxLength));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "type", {
        /**
         * Returns type.
         *
         * @return Type. Defaults to "text".
         */
        get: function () {
            return this.getAttributeNS(null, 'type') || 'text';
        },
        /**
         * Sets type.
         *
         * @param type Type.
         */
        set: function (type) {
            this.setAttributeNS(null, 'type', type.toLowerCase());
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "name", {
        /**
         * Returns name.
         *
         * @return Name.
         */
        get: function () {
            return this.getAttributeNS(null, 'name') || '';
        },
        /**
         * Sets name.
         *
         * @param name Name.
         */
        set: function (name) {
            this.setAttributeNS(null, 'name', name);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "alt", {
        /**
         * Returns alt.
         *
         * @return Alt.
         */
        get: function () {
            return this.getAttributeNS(null, 'alt') || '';
        },
        /**
         * Sets alt.
         *
         * @param alt Alt.
         */
        set: function (alt) {
            this.setAttributeNS(null, 'alt', alt);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "min", {
        /**
         * Returns min.
         *
         * @return Min.
         */
        get: function () {
            return this.getAttributeNS(null, 'min') || '';
        },
        /**
         * Sets min.
         *
         * @param min Min.
         */
        set: function (min) {
            this.setAttributeNS(null, 'min', min);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "max", {
        /**
         * Returns max.
         *
         * @return Max.
         */
        get: function () {
            return this.getAttributeNS(null, 'max') || '';
        },
        /**
         * Sets max.
         *
         * @param max Max.
         */
        set: function (max) {
            this.setAttributeNS(null, 'max', max);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "pattern", {
        /**
         * Returns pattern.
         *
         * @return Pattern.
         */
        get: function () {
            return this.getAttributeNS(null, 'pattern') || '';
        },
        /**
         * Sets pattern.
         *
         * @param pattern Pattern.
         */
        set: function (pattern) {
            this.setAttributeNS(null, 'pattern', pattern);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "placeholder", {
        /**
         * Returns placeholder.
         *
         * @return Placeholder.
         */
        get: function () {
            return this.getAttributeNS(null, 'placeholder') || '';
        },
        /**
         * Sets placeholder.
         *
         * @param placeholder Placeholder.
         */
        set: function (placeholder) {
            this.setAttributeNS(null, 'placeholder', placeholder);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "step", {
        /**
         * Returns step.
         *
         * @return Step.
         */
        get: function () {
            return this.getAttributeNS(null, 'step') || '';
        },
        /**
         * Sets step.
         *
         * @param step Step.
         */
        set: function (step) {
            this.setAttributeNS(null, 'step', step);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "inputmode", {
        /**
         * Returns inputmode.
         *
         * @return Inputmode.
         */
        get: function () {
            return this.getAttributeNS(null, 'inputmode') || '';
        },
        /**
         * Sets inputmode.
         *
         * @param inputmode Inputmode.
         */
        set: function (inputmode) {
            this.setAttributeNS(null, 'inputmode', inputmode);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "accept", {
        /**
         * Returns accept.
         *
         * @return Accept.
         */
        get: function () {
            return this.getAttributeNS(null, 'accept') || '';
        },
        /**
         * Sets accept.
         *
         * @param accept Accept.
         */
        set: function (accept) {
            this.setAttributeNS(null, 'accept', accept);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "allowdirs", {
        /**
         * Returns allowdirs.
         *
         * @return Allowdirs.
         */
        get: function () {
            return this.getAttributeNS(null, 'allowdirs') || '';
        },
        /**
         * Sets allowdirs.
         *
         * @param allowdirs Allowdirs.
         */
        set: function (allowdirs) {
            this.setAttributeNS(null, 'allowdirs', allowdirs);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "autocomplete", {
        /**
         * Returns autocomplete.
         *
         * @return Autocomplete.
         */
        get: function () {
            return this.getAttributeNS(null, 'autocomplete') || '';
        },
        /**
         * Sets autocomplete.
         *
         * @param autocomplete Autocomplete.
         */
        set: function (autocomplete) {
            this.setAttributeNS(null, 'autocomplete', autocomplete);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "src", {
        /**
         * Returns src.
         *
         * @return Src.
         */
        get: function () {
            return this.getAttributeNS(null, 'src') || '';
        },
        /**
         * Sets src.
         *
         * @param src Src.
         */
        set: function (src) {
            this.setAttributeNS(null, 'src', src);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "defaultvalue", {
        /**
         * Returns defaultvalue.
         *
         * @return Defaultvalue.
         */
        get: function () {
            return this.getAttributeNS(null, 'defaultvalue') || '';
        },
        /**
         * Sets defaultvalue.
         *
         * @param defaultvalue Defaultvalue.
         */
        set: function (defaultvalue) {
            this.setAttributeNS(null, 'defaultvalue', defaultvalue);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "readOnly", {
        /**
         * Returns read only.
         *
         * @return Read only.
         */
        get: function () {
            return this.getAttributeNS(null, 'readonly') !== null;
        },
        /**
         * Sets read only.
         *
         * @param readOnly Read only.
         */
        set: function (readOnly) {
            if (!readOnly) {
                this.removeAttributeNS(null, 'readonly');
            }
            else {
                this.setAttributeNS(null, 'readonly', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "disabled", {
        /**
         * Returns disabled.
         *
         * @return Disabled.
         */
        get: function () {
            return this.getAttributeNS(null, 'disabled') !== null;
        },
        /**
         * Sets disabled.
         *
         * @param disabled Disabled.
         */
        set: function (disabled) {
            if (!disabled) {
                this.removeAttributeNS(null, 'disabled');
            }
            else {
                this.setAttributeNS(null, 'disabled', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "autofocus", {
        /**
         * Returns autofocus.
         *
         * @return Autofocus.
         */
        get: function () {
            return this.getAttributeNS(null, 'autofocus') !== null;
        },
        /**
         * Sets autofocus.
         *
         * @param autofocus Autofocus.
         */
        set: function (autofocus) {
            if (!autofocus) {
                this.removeAttributeNS(null, 'autofocus');
            }
            else {
                this.setAttributeNS(null, 'autofocus', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "required", {
        /**
         * Returns required.
         *
         * @return Required.
         */
        get: function () {
            return this.getAttributeNS(null, 'required') !== null;
        },
        /**
         * Sets required.
         *
         * @param required Required.
         */
        set: function (required) {
            if (!required) {
                this.removeAttributeNS(null, 'required');
            }
            else {
                this.setAttributeNS(null, 'required', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "indeterminate", {
        /**
         * Returns indeterminate.
         *
         * @return Indeterminate.
         */
        get: function () {
            return this.getAttributeNS(null, 'indeterminate') !== null;
        },
        /**
         * Sets indeterminate.
         *
         * @param indeterminate Indeterminate.
         */
        set: function (indeterminate) {
            if (!indeterminate) {
                this.removeAttributeNS(null, 'indeterminate');
            }
            else {
                this.setAttributeNS(null, 'indeterminate', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "multiple", {
        /**
         * Returns multiple.
         *
         * @return Multiple.
         */
        get: function () {
            return this.getAttributeNS(null, 'multiple') !== null;
        },
        /**
         * Sets multiple.
         *
         * @param multiple Multiple.
         */
        set: function (multiple) {
            if (!multiple) {
                this.removeAttributeNS(null, 'multiple');
            }
            else {
                this.setAttributeNS(null, 'multiple', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "checked", {
        /**
         * Returns checked.
         *
         * @return Checked.
         */
        get: function () {
            return this.getAttributeNS(null, 'checked') !== null;
        },
        /**
         * Sets checked.
         *
         * @param checked Checked.
         */
        set: function (checked) {
            if (!checked) {
                this.removeAttributeNS(null, 'checked');
            }
            else {
                this.setAttributeNS(null, 'checked', '');
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "value", {
        /**
         * Returns value.
         *
         * @return Value.
         */
        get: function () {
            switch (this.type) {
                case 'hidden':
                case 'submit':
                case 'image':
                case 'reset':
                case 'button':
                    return this.getAttributeNS(null, 'value') || '';
                case 'checkbox':
                case 'radio':
                    var attritube = this.getAttributeNS(null, 'value');
                    return attritube !== null ? attritube : 'on';
                case 'file':
                    return this.files.length > 0 ? '/fake/path/' + this.files[0].name : '';
            }
            if (this._value === null) {
                return this.getAttributeNS(null, 'value') || '';
            }
            return this._value;
        },
        /**
         * Sets value.
         *
         * @param value Value.
         */
        set: function (value) {
            switch (this.type) {
                case 'hidden':
                case 'submit':
                case 'image':
                case 'reset':
                case 'button':
                case 'checkbox':
                case 'radio':
                    this.setAttributeNS(null, 'value', value);
                    break;
                case 'file':
                    if (value !== '') {
                        throw new DOMException_1.default('Input elements of type "file" may only programmatically set the value to empty string.', DOMExceptionNameEnum_1.default.invalidStateError);
                    }
                    break;
                default:
                    var oldValue = this._value;
                    this._value = HTMLInputElementValueSanitizer_1.default.sanitize(this, value);
                    if (oldValue !== this._value) {
                        this._selectionStart = this._value.length;
                        this._selectionEnd = this._value.length;
                        this._selectionDirection = HTMLInputElementSelectionDirectionEnum_1.default.none;
                    }
                    break;
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "selectionStart", {
        /**
         * Returns selection start.
         *
         * @return Selection start.
         */
        get: function () {
            if (!this._isSelectionSupported()) {
                return null;
            }
            if (this._selectionStart === null) {
                return this.value.length;
            }
            return this._selectionStart;
        },
        /**
         * Sets selection start.
         *
         * @param start Start.
         */
        set: function (start) {
            if (!this._isSelectionSupported()) {
                throw new DOMException_1.default("The input element's type (" + this.type + ") does not support selection.", DOMExceptionNameEnum_1.default.invalidStateError);
            }
            this.setSelectionRange(start, Math.max(start, this.selectionEnd), this._selectionDirection);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "selectionEnd", {
        /**
         * Returns selection end.
         *
         * @return Selection end.
         */
        get: function () {
            if (!this._isSelectionSupported()) {
                return null;
            }
            if (this._selectionEnd === null) {
                return this.value.length;
            }
            return this._selectionEnd;
        },
        /**
         * Sets selection end.
         *
         * @param end End.
         */
        set: function (end) {
            if (!this._isSelectionSupported()) {
                throw new DOMException_1.default("The input element's type (" + this.type + ") does not support selection.", DOMExceptionNameEnum_1.default.invalidStateError);
            }
            this.setSelectionRange(this.selectionStart, end, this._selectionDirection);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "selectionDirection", {
        /**
         * Returns selection direction.
         *
         * @return Selection direction.
         */
        get: function () {
            if (!this._isSelectionSupported()) {
                return null;
            }
            return this._selectionDirection;
        },
        /**
         * Sets selection direction.
         *
         * @param direction Direction.
         */
        set: function (direction) {
            if (!this._isSelectionSupported()) {
                throw new DOMException_1.default("The input element's type (" + this.type + ") does not support selection.", DOMExceptionNameEnum_1.default.invalidStateError);
            }
            this.setSelectionRange(this._selectionStart, this._selectionEnd, direction);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "form", {
        /**
         * Returns the parent form element.
         *
         * @return Form.
         */
        get: function () {
            var parent = this.parentNode;
            while (parent && parent.tagName !== 'FORM') {
                parent = parent.parentNode;
            }
            return parent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "validity", {
        /**
         * Returns validity state.
         *
         * @returns Validity state.
         */
        get: function () {
            return new ValidityState_1.default(this);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "validationMessage", {
        /**
         * Returns validity message.
         *
         * @return Validation message.
         */
        get: function () {
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "willValidate", {
        /**
         * Returns "true" if it will validate.
         *
         * @return "true" if it will validate.
         */
        get: function () {
            return (this.type !== 'hidden' &&
                this.type !== 'reset' &&
                this.type !== 'button' &&
                !this.disabled &&
                !this['readOnly']);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "valueAsDate", {
        /**
         * Returns value as Date.
         *
         * @returns Date.
         */
        get: function () {
            return this.value ? new Date(this.value) : null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "valueAsNumber", {
        /**
         * Returns value as number.
         *
         * @return Number.
         */
        get: function () {
            return this.value ? parseFloat(this.value) : NaN;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Set selection range.
     *
     * @param start Start.
     * @param end End.
     * @param [direction="none"] Direction.
     */
    HTMLInputElement.prototype.setSelectionRange = function (start, end, direction) {
        if (direction === void 0) { direction = 'none'; }
        if (!this._isSelectionSupported()) {
            throw new DOMException_1.default("The input element's type (" + this.type + ") does not support selection.", DOMExceptionNameEnum_1.default.invalidStateError);
        }
        this._selectionEnd = Math.min(end, this.value.length);
        this._selectionStart = Math.min(start, this._selectionEnd);
        this._selectionDirection =
            direction === HTMLInputElementSelectionDirectionEnum_1.default.forward ||
                direction === HTMLInputElementSelectionDirectionEnum_1.default.backward
                ? direction
                : HTMLInputElementSelectionDirectionEnum_1.default.none;
        this.dispatchEvent(new Event_1.default('select', { bubbles: true, cancelable: true }));
    };
    /**
     * Set range text.
     *
     * @param replacement Replacement.
     * @param [start] Start.
     * @param [end] End.
     * @param [direction] Direction.
     */
    HTMLInputElement.prototype.setRangeText = function (replacement, start, end, selectionMode) {
        if (start === void 0) { start = null; }
        if (end === void 0) { end = null; }
        if (selectionMode === void 0) { selectionMode = HTMLInputElementSelectionModeEnum_1.default.preserve; }
        if (!this._isSelectionSupported()) {
            throw new DOMException_1.default("The input element's type (" + this.type + ") does not support selection.", DOMExceptionNameEnum_1.default.invalidStateError);
        }
        if (start === null) {
            start = this._selectionStart;
        }
        if (end === null) {
            end = this._selectionEnd;
        }
        if (start > end) {
            throw new DOMException_1.default('The index is not in the allowed range.', DOMExceptionNameEnum_1.default.invalidStateError);
        }
        start = Math.min(start, this.value.length);
        end = Math.min(end, this.value.length);
        var val = this.value;
        var selectionStart = this._selectionStart;
        var selectionEnd = this._selectionEnd;
        this.value = val.slice(0, start) + replacement + val.slice(end);
        var newEnd = start + this.value.length;
        switch (selectionMode) {
            case HTMLInputElementSelectionModeEnum_1.default.select:
                this.setSelectionRange(start, newEnd);
                break;
            case HTMLInputElementSelectionModeEnum_1.default.start:
                this.setSelectionRange(start, start);
                break;
            case HTMLInputElementSelectionModeEnum_1.default.end:
                this.setSelectionRange(newEnd, newEnd);
                break;
            default:
                var delta = replacement.length - (end - start);
                if (selectionStart > end) {
                    selectionStart += delta;
                }
                else if (selectionStart > start) {
                    selectionStart = start;
                }
                if (selectionEnd > end) {
                    selectionEnd += delta;
                }
                else if (selectionEnd > start) {
                    selectionEnd = newEnd;
                }
                this.setSelectionRange(selectionStart, selectionEnd);
                break;
        }
    };
    /**
     * Checks validity.
     *
     * @return "true" if the field is valid.
     */
    HTMLInputElement.prototype.checkValidity = function () {
        return true;
    };
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    HTMLInputElement.prototype.cloneNode = function (deep) {
        if (deep === void 0) { deep = false; }
        var clone = _super.prototype.cloneNode.call(this, deep);
        clone.formAction = this.formAction;
        clone.formMethod = this.formMethod;
        clone.formNoValidate = this.formNoValidate;
        clone._value = this._value;
        clone._height = this._height;
        clone._width = this._width;
        clone.defaultChecked = this.defaultChecked;
        clone.files = this.files.slice();
        clone._selectionStart = this._selectionStart;
        clone._selectionEnd = this._selectionEnd;
        clone._selectionDirection = this._selectionDirection;
        return clone;
    };
    /**
     * Checks if private value is supported.
     *
     * @returns "true" if private value is supported.
     */
    // private _isPrivateValueSupported(): boolean {
    // 	return (
    // 		this.type !== 'hidden' &&
    // 		this.type !== 'submit' &&
    // 		this.type !== 'image' &&
    // 		this.type !== 'reset' &&
    // 		this.type !== 'button' &&
    // 		this.type !== 'checkbox' &&
    // 		this.type !== 'radio' &&
    // 		this.type !== 'file'
    // 	);
    // }
    /**
     * Checks is selection is supported.
     *
     * @returns "true" if selection is supported.
     */
    HTMLInputElement.prototype._isSelectionSupported = function () {
        return (this.type === 'text' ||
            this.type === 'search' ||
            this.type === 'url' ||
            this.type === 'tel' ||
            this.type === 'password');
    };
    return HTMLInputElement;
}(HTMLElement_1.default));
exports.default = HTMLInputElement;
//# sourceMappingURL=HTMLInputElement.js.map